# -*- coding: UTF-8 -*-

from threading import RLock

RLOCK: RLock = RLock()
